@@ -56,14 +56,17 @@ echo -n "checking for automake >= $AUTOMAKE_REQUIRED_VERSION ... "
 if (automake-1.7 --version) < /dev/null > /dev/null 2>&1; then
    AUTOMAKE=automake-1.7
    ACLOCAL=aclocal-1.7
+elif (automake-1.8 --version) < /dev/null > /dev/null 2>&1; then
+   AUTOMAKE=automake-1.8
+   ACLOCAL=aclocal-1.8
 elif (automake-1.6 --version) < /dev/null > /dev/null 2>&1; then
    AUTOMAKE=automake-1.6
    ACLOCAL=aclocal-1.6
 else
     echo
-    echo "  You must have automake 1.6 or 1.7 installed to compile $PROJECT."
-    echo "  Get ftp://ftp.gnu.org/pub/gnu/automake/automake-1.7.3.tar.gz"
-    echo "  (or a newer version if it is available)"
+    echo "  You must have automake 1.6 or newer installed to compile $PROJECT."
+    echo "  Download the appropriate package for your distribution,"
+    echo "  or get the source tarball at ftp://ftp.gnu.org/pub/gnu/automake/"
     DIE=1
 fi
 
@@ -125,7 +128,7 @@ fi
 if test -z "$ACLOCAL_FLAGS"; then
 
     acdir=`$ACLOCAL --print-ac-dir`
-    m4list="gimp-2.0.m4 glib-gettext.m4 intltool.m4"
+    m4list="glib-gettext.m4 intltool.m4"
 
     for file in $m4list
     do
