@@ -30,8 +30,8 @@
 #include <libgimp/gimp.h>
 #include <libgimp/gimpui.h>
 
-#include "interface.h"
 #include "main.h"
+#include "interface.h"
 
 #include "plugin-intl.h"
 
@@ -162,7 +162,7 @@ dialog (gint32              image_ID,
   gtk_container_add (GTK_CONTAINER (frame), hbox);
   gtk_widget_show (hbox);
 
-  hbox2 = gimp_random_seed_new (&vals->seed);
+  hbox2 = gimp_random_seed_new (&vals->seed, &vals->random_seed);
   gtk_widget_set_size_request (GTK_WIDGET (GIMP_RANDOM_SEED_SPINBUTTON (hbox2)),
                                RANDOM_SEED_WIDTH, -1);
   gtk_box_pack_start (GTK_BOX (hbox), hbox2, FALSE, FALSE, 0);
