@@ -32,8 +32,8 @@
 #include <libgimp/gimp.h>
 #include <libgimp/gimpui.h>
 
-#include "interface.h"
 #include "main.h"
+#include "interface.h"
 #include "render.h"
 
 #include "plugin-intl.h"
@@ -66,7 +66,8 @@ const PlugInVals default_vals =
   0,
   1,
   2,
-  0
+  0,
+  FALSE
 };
 
 const PlugInImageVals default_image_vals =
@@ -108,13 +109,14 @@ query (void)
 
   static GimpParamDef args[] =
   {
-    { GIMP_PDB_INT32,    "run_mode",   "Interactive, non-interactive"       },
-    { GIMP_PDB_IMAGE,    "image",      "Input image"                        },
-    { GIMP_PDB_DRAWABLE, "drawable",   "Input drawable"                     },
-    { GIMP_PDB_INT32,    "dummy",      "dummy1"                             },
-    { GIMP_PDB_INT32,    "dummy",      "dummy2"                             },
-    { GIMP_PDB_INT32,    "dummy",      "dummy3"                             },
-    { GIMP_PDB_INT32,    "seed",       "Random seed value"                  }
+    { GIMP_PDB_INT32,    "run_mode",   "Interactive, non-interactive"    },
+    { GIMP_PDB_IMAGE,    "image",      "Input image"                     },
+    { GIMP_PDB_DRAWABLE, "drawable",   "Input drawable"                  },
+    { GIMP_PDB_INT32,    "dummy",      "dummy1"                          },
+    { GIMP_PDB_INT32,    "dummy",      "dummy2"                          },
+    { GIMP_PDB_INT32,    "dummy",      "dummy3"                          },
+    { GIMP_PDB_INT32,    "seed",       "Seed value (used only if randomize is FALSE)" },
+    { GIMP_PDB_INT32,    "randomize",  "Use a random seed (TRUE, FALSE)" }
   };
 
   gimp_plugin_domain_register (PLUGIN_NAME, LOCALEDIR);
@@ -131,7 +133,7 @@ query (void)
 			  "Help",
 			  "Michael Natterer <mitch@gimp.org>",
 			  "Michael Natterer <mitch@gimp.org>",
-			  "2000-2003",
+			  "2000-2004",
 			  N_("<Image>/Filters/Misc/Plug-In Template..."),
 			  "RGB*, GRAY*, INDEXED*",
 			  GIMP_PLUGIN,
@@ -177,16 +179,20 @@ run (const gchar      *name,
       switch (run_mode)
 	{
 	case GIMP_RUN_NONINTERACTIVE:
-	  if (n_params != 7)
+	  if (n_params != 8)
 	    {
 	      status = GIMP_PDB_CALLING_ERROR;
 	    }
 	  else
 	    {
-	      vals.dummy1 = param[3].data.d_int32;
-	      vals.dummy2 = param[4].data.d_int32;
-	      vals.dummy3 = param[5].data.d_int32;
-	      vals.seed   = param[6].data.d_int32;
+	      vals.dummy1      = param[3].data.d_int32;
+	      vals.dummy2      = param[4].data.d_int32;
+	      vals.dummy3      = param[5].data.d_int32;
+	      vals.seed        = param[6].data.d_int32;
+	      vals.random_seed = param[7].data.d_int32;
+
+              if (vals.random_seed)
+                vals.seed = g_random_int ();
 	    }
 	  break;
 
@@ -205,6 +211,9 @@ run (const gchar      *name,
 	case GIMP_RUN_WITH_LAST_VALS:
 	  /*  Possibly retrieve data  */
 	  gimp_get_data (DATA_KEY_VALS, &vals);
+
+          if (vals.random_seed)
+            vals.seed = g_random_int ();
 	  break;
 
 	default:
